summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlwidgetcontroller.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umlwidgetcontroller.h')
-rw-r--r--umbrello/umbrello/umlwidgetcontroller.h68
1 files changed, 34 insertions, 34 deletions
diff --git a/umbrello/umbrello/umlwidgetcontroller.h b/umbrello/umbrello/umlwidgetcontroller.h
index 552ea174..a21ba930 100644
--- a/umbrello/umbrello/umlwidgetcontroller.h
+++ b/umbrello/umbrello/umlwidgetcontroller.h
@@ -13,7 +13,7 @@
#define UMLWIDGETCONTROLLER_H
// qt includes
-#include <qdatetime.h>
+#include <tqdatetime.h>
// app includes
#include "umlwidgetlist.h"
@@ -104,9 +104,9 @@ public:
* it's marked to be deselected when releasing the button (provided it wasn't
* moved or resized).
*
* @param me The QMouseEvent event.
*/
- virtual void mousePressEvent(QMouseEvent *me);
+ virtual void mousePressEvent(TQMouseEvent *me);
/**
* Handles a mouse move event.
@@ -137,9 +137,9 @@ public:
* not updated always to be easy on the CPU). Finally, the canvas is resized,
* and selection bounds updated.
*
* @param me The QMouseEvent event.
*/
- virtual void mouseMoveEvent(QMouseEvent* me);
+ virtual void mouseMoveEvent(TQMouseEvent* me);
/**
* Handles a mouse release event.
@@ -162,9 +162,9 @@ public:
* event at the same position than the cursor was when pressed. Another left
* button release is also sent.
*
* @param me The QMouseEvent event.
*/
- virtual void mouseReleaseEvent(QMouseEvent * me);
+ virtual void mouseReleaseEvent(TQMouseEvent * me);
/**
* Handles a mouse double click event.
@@ -173,9 +173,9 @@ public:
* doMouseDoubleClick.
* @see doMouseDoubleClick
*
* @param me The QMouseEvent event.
*/
- virtual void mouseDoubleClickEvent(QMouseEvent *me);
+ virtual void mouseDoubleClickEvent(TQMouseEvent *me);
protected:
@@ -189,9 +189,9 @@ protected:
* resize begins. However, parent method (that is, this method) must be
* called in the overridden method.
*
* @param me The QMouseEvent to get the offset from.
*/
- virtual void saveWidgetValues(QMouseEvent *me);
+ virtual void saveWidgetValues(TQMouseEvent *me);
/**
* Checks if the mouse is in resize area (right bottom corner), and sets
@@ -201,7 +201,7 @@ protected:
* @param me The QMouseEVent to check.
* @return true if the mouse is in resize area, false otherwise.
*/
- virtual bool isInResizeArea(QMouseEvent *me);
+ virtual bool isInResizeArea(TQMouseEvent *me);
/**
* Returns the cursor to be shown when resizing the widget.
@@ -210,7 +210,7 @@ protected:
*
* @return The cursor to be shown when resizing the widget.
*/
- virtual QCursor getResizeCursor();
+ virtual TQCursor getResizeCursor();
/**
* Resizes the widget.
@@ -274,9 +274,9 @@ protected:
* don't have an UMLObject representation) there's no need to override
* the method, it simply does nothing.
*
* @param me The QMouseEvent which triggered the double click event.
*/
- virtual void doMouseDoubleClick(QMouseEvent *me);
+ virtual void doMouseDoubleClick(TQMouseEvent *me);
/**
* Clears the selection, resets the toolbar and deselects the widget.
@@ -286,23 +286,23 @@ protected:
/**
* Selects the widget and clears the other selected widgets, if any.
*
* @param me The QMouseEvent which made the selection.
*/
- void selectSingle(QMouseEvent *me);
+ void selectSingle(TQMouseEvent *me);
/**
* Selects the widget and adds it to the list of selected widgets.
*
* @param me The QMouseEvent which made the selection.
*/
- void selectMultiple(QMouseEvent *me);
+ void selectMultiple(TQMouseEvent *me);
/**
* Deselects the widget and removes it from the list of selected widgets.
*
* @param me The QMouseEvent which made the selection.
*/
- void deselect(QMouseEvent *me);
+ void deselect(TQMouseEvent *me);
/**
* Fills m_selectedWidgetsList and sets the selection bounds ((m_min/m_max)X/Y attributes).
@@ -325,9 +325,9 @@ protected:
* in resize area when pressed.
* Resizing can be constrained to an specific axis using control and shift buttons.
*
* @param me The QMouseEvent to get the values from.
*/
- void resize(QMouseEvent *me);
+ void resize(TQMouseEvent *me);
/**
* Returns the smallest X position of all the widgets in the list.
@@ -367,26 +367,26 @@ protected:
* m_widget->get{X,Y}(), the previous position m_old{X,Y}, and the
* mouse press offset m_pressOffset{X,Y}.
*
* @param me The QMouseEvent for which to get the adjusted position.
* @return A QPoint with the adjusted position.
*/
- QPoint getPosition(QMouseEvent *me);
+ TQPoint getPosition(TQMouseEvent *me);
/**
* Returns a QPoint with the new X and Y position difference of the mouse event
* respect to the position of the widget.
*
* @param me The QMouseEvent to get the position to compare.
* @return A QPoint with the position difference.
*/
- QPoint getPositionDifference(QMouseEvent *me);
+ TQPoint getPositionDifference(TQMouseEvent *me);
/**
* Shows the widget popup menu where the mouse event points to.
*
* @param me The QMouseEvent which triggered the showing.
*/
- void showPopupMenu(QMouseEvent *me);
+ void showPopupMenu(TQMouseEvent *me);
/**
* Checks if the size of the widget changed respect to the size that
@@ -412,7 +412,7 @@ protected:
/**
* Timer that prevents excessive updates (be easy on the CPU).
*/
- QTime lastUpdate;
+ TQTime lastUpdate;
/**
* A list containing the selected widgets.
@@ -426,7 +426,7 @@ protected:
/**
* The text in the status bar when the cursor was pressed.
*/
- QString m_oldStatusBarMsg;
+ TQString m_oldStatusBarMsg;
/**
* The X/Y offset from the position of the cursor when it was pressed to the
@@ -104,9 +104,9 @@ public:
* moved or resized).
*
- * @param me The QMouseEvent event.
+ * @param me The TQMouseEvent event.
*/
@@ -137,9 +137,9 @@ public:
* and selection bounds updated.
*
- * @param me The QMouseEvent event.
+ * @param me The TQMouseEvent event.
*/
@@ -162,9 +162,9 @@ public:
* button release is also sent.
*
- * @param me The QMouseEvent event.
+ * @param me The TQMouseEvent event.
*/
@@ -173,9 +173,9 @@ public:
* @see doMouseDoubleClick
*
- * @param me The QMouseEvent event.
+ * @param me The TQMouseEvent event.
*/
@@ -189,9 +189,9 @@ protected:
* called in the overridden method.
*
- * @param me The QMouseEvent to get the offset from.
+ * @param me The TQMouseEvent to get the offset from.
*/
@@ -274,9 +274,9 @@ protected:
* the method, it simply does nothing.
*
- * @param me The QMouseEvent which triggered the double click event.
+ * @param me The TQMouseEvent which triggered the double click event.
*/
@@ -286,23 +286,23 @@ protected:
* Selects the widget and clears the other selected widgets, if any.
*
- * @param me The QMouseEvent which made the selection.
+ * @param me The TQMouseEvent which made the selection.
*/
@@ -286,23 +286,23 @@ protected:
* Selects the widget and adds it to the list of selected widgets.
*
- * @param me The QMouseEvent which made the selection.
+ * @param me The TQMouseEvent which made the selection.
*/
@@ -286,23 +286,23 @@ protected:
* Deselects the widget and removes it from the list of selected widgets.
*
- * @param me The QMouseEvent which made the selection.
+ * @param me The TQMouseEvent which made the selection.
*/
@@ -325,9 +325,9 @@ protected:
* Resizing can be constrained to an specific axis using control and shift buttons.
*
- * @param me The QMouseEvent to get the values from.
+ * @param me The TQMouseEvent to get the values from.
*/
@@ -367,26 +367,26 @@ protected:
* mouse press offset m_pressOffset{X,Y}.
*
- * @param me The QMouseEvent for which to get the adjusted position.
- * @return A QPoint with the adjusted position.
+ * @param me The TQMouseEvent for which to get the adjusted position.
+ * @return A TQPoint with the adjusted position.
*/
@@ -367,26 +367,26 @@ protected:
/**
- * Returns a QPoint with the new X and Y position difference of the mouse event
+ * Returns a TQPoint with the new X and Y position difference of the mouse event
* respect to the position of the widget.
*
@@ -367,26 +367,26 @@ protected:
* respect to the position of the widget.
*
- * @param me The QMouseEvent to get the position to compare.
- * @return A QPoint with the position difference.
+ * @param me The TQMouseEvent to get the position to compare.
+ * @return A TQPoint with the position difference.
*/
@@ -367,26 +367,26 @@ protected:
* Shows the widget popup menu where the mouse event points to.
*
- * @param me The QMouseEvent which triggered the showing.
+ * @param me The TQMouseEvent which triggered the showing.
*/